// AUTOGENERATED FILE - DO NOT EDIT

var pt = window.PropTypes;
var pk = window['dash_prism'];

pk.PrismActionComponent.propTypes = {label:pt.string,
 icon:pt.string,
 tooltip:pt.string,
 style:pt.any,
 disabled:pt.bool,
 loading:pt.bool,
 n_clicks:pt.number,
 id:pt.string,
 setProps:pt.any};
pk.PrismComponent.propTypes = {id:pt.string,
 serverSessionId:pt.string,
 children:pt.node,
 registeredLayouts:pt.objectOf(pt.shape({name:pt.string,description:pt.string,keywords:pt.arrayOf(pt.string),allowMultiple:pt.bool,params:pt.arrayOf(pt.shape({name:pt.string,hasDefault:pt.bool,default:pt.string})),paramOptions:pt.shape({})})),
 theme:pt.oneOf(["'light'", "'dark'"]),
 size:pt.oneOf(["'sm'", "'md'", "'lg'"]),
 maxTabs:pt.number,
 searchBarPlaceholder:pt.string,
 layoutTimeout:pt.number,
 statusBarPosition:pt.oneOf(["'top'", "'bottom'"]),
 readWorkspace:pt.shape({tabs:pt.arrayOf(pt.shape({id:pt.string,name:pt.string,panelId:pt.string,createdAt:pt.number,layoutId:pt.string,layoutOption:pt.string,layoutParams:pt.objectOf(pt.string),locked:pt.bool,mountKey:pt.string,icon:pt.string,style:pt.string})),panel:pt.shape({id:pt.string,order:pt.oneOf([0, 1]),direction:pt.oneOf(["'vertical'", "'horizontal'"]),pinned:pt.bool,children:pt.arrayOf(pt.any),size:pt.oneOfType([pt.string,pt.number])}),panelTabs:pt.objectOf(pt.arrayOf(pt.string)),activeTabIds:pt.objectOf(pt.string),activePanelId:pt.string,favoriteLayouts:pt.arrayOf(pt.string),theme:pt.oneOf(["'light'", "'dark'"]),searchBarsHidden:pt.bool}),
 updateWorkspace:pt.shape({tabs:pt.arrayOf(pt.shape({id:pt.string,name:pt.string,panelId:pt.string,createdAt:pt.number,layoutId:pt.string,layoutOption:pt.string,layoutParams:pt.objectOf(pt.string),locked:pt.bool,mountKey:pt.string,icon:pt.string,style:pt.string})),panel:pt.shape({id:pt.string,order:pt.oneOf([0, 1]),direction:pt.oneOf(["'vertical'", "'horizontal'"]),pinned:pt.bool,children:pt.arrayOf(pt.any),size:pt.oneOfType([pt.string,pt.number])}),panelTabs:pt.objectOf(pt.arrayOf(pt.string)),activeTabIds:pt.objectOf(pt.string),activePanelId:pt.string,favoriteLayouts:pt.arrayOf(pt.string),theme:pt.oneOf(["'light'", "'dark'"]),searchBarsHidden:pt.bool}),
 actions:pt.arrayOf(pt.node),
 persistence:pt.bool,
 persistence_type:pt.oneOf(["'memory'", "'session'", "'local'"]),
 initialLayout:pt.string,
 style:pt.any,
 setProps:pt.any};
pk.PrismContentComponent.propTypes = {children:pt.node,
 data:pt.shape({tabId:pt.string,layoutId:pt.string,layoutParams:pt.objectOf(pt.string),layoutOption:pt.string}),
 layoutTimeout:pt.number,
 id:pt.string,
 setProps:pt.any};
